@@ -7,7 +7,6 @@ from django.contrib.contenttypes.models import ContentType
 from wagtail.core.models import Page, Site
 from wagtail.images.models import Image
 
-from webspace.cms.models import MyDocument
 from webspace.cms import constants
 from webspace.loader import get_model, get_class
 from webspace.cms.blocks.mocker import Mocker
@@ -37,6 +36,7 @@ ContentPage = get_model('cms', 'ContentPage')
 BlogPage = get_model('cms', 'BlogPage')
 BlogIndexPage = get_model('cms', 'BlogIndexPage')
 WebspaceSettings = get_model('cms', 'WebspaceSettings')
+MyDocument = get_model('cms', 'MyDocument')
 
 
 class Command(BaseCommand):
