@@ -8,29 +8,34 @@ from webspace.loader import is_model_registered
 __all__ = []
 
 
-class MyDocument(AbstractDocument):
-    #  Dimensions for SVG
+if not is_model_registered('cms', 'MyDocument'):
+    class MyDocument(AbstractDocument):
+        #  Dimensions for SVG
 
-    width = models.IntegerField(
-        default=None,
-        blank=True,
-        null=True,
-        help_text="for SVG"
-    )
-    height = models.IntegerField(
-        default=None,
-        blank=True,
-        null=True,
-        help_text="for SVG"
-    )
+        width = models.IntegerField(
+            default=None,
+            blank=True,
+            null=True,
+            help_text="for SVG"
+        )
+        height = models.IntegerField(
+            default=None,
+            blank=True,
+            null=True,
+            help_text="for SVG"
+        )
 
-    admin_form_fields = Document.admin_form_fields + (
-        'width',
-        'height'
-    )
+        admin_form_fields = Document.admin_form_fields + (
+            'width',
+            'height'
+        )
 
-    def get_size(self):
-        return '500x500'
+        def get_size(self):
+            return '500x500'
+
+        class Meta:
+            verbose_name = "MyDocument"
+            app_label = 'cms'
 
 
 __all__.append('MyDocument')
@@ -129,7 +134,7 @@ if not is_model_registered('cms', 'DocumentPage'):
 
 #  Settings
 
-from .settings.webspace import AWebspaceSettings
+from .settings.webspace import AWebspaceSettings, AFounders
 
 if not is_model_registered('cms', 'WebspaceSettings'):
     @register_setting
@@ -138,3 +143,12 @@ if not is_model_registered('cms', 'WebspaceSettings'):
 
 
     __all__.append('WebspaceSettings')
+
+
+if not is_model_registered('cms', 'Founders'):
+    @register_setting
+    class Founders(AFounders):
+        pass
+
+
+    __all__.append('Founders')
